pub struct ClientSideRefresh { /* private fields */ }Expand description
Client-side “redirect:” by default, a meta refresh tag, but can be configured to return a custom response.
Implementations
Sourceimpl ClientSideRefresh
impl ClientSideRefresh
Sourcepub fn from_path(path: impl AsRef<str>) -> Self
pub fn from_path(path: impl AsRef<str>) -> Self
Create a new instance, with the location to which this strategy will redirect the browser.
The redirect will be implemented as client-side “Meta Refresh” that instructs the browser to navigate to the given path immediately after loading the page.
Sourcepub fn from_body(body: impl AsRef<str>) -> Self
pub fn from_body(body: impl AsRef<str>) -> Self
Create a new instance, with the raw HTML body that will be returned to the browser in order to trigger the refresh.
Sourcepub fn with_header(
self,
name: impl Into<HeaderName>,
values: impl ToHeaderValues,
) -> Self
pub fn with_header( self, name: impl Into<HeaderName>, values: impl ToHeaderValues, ) -> Self
Adds a header to the client-side refresh response, usually in
cases where a client-side framework is using the
XMLHttpRequest or fetch APIs to send requests, and watches
for a specific response header in order to effect a client-side
redirect.